==> Tagz-1.0.0.zip: Tagz/Tagz.php <==
<?php
/**
* Plugin Tagz
* @package	PLX
* @version	1.0.0
* @date	23/12/2018
* @author Thomas Ingles
**/
class Tagz extends plxPlugin {
	public function __construct($default_lang) {
		parent::__construct($default_lang);# appel du constructeur de la classe plxPlugin (obligatoire)
		if(defined('PLX_ADMIN')){#si administration
# droits pour accéder à la page config.php du plugin
			$this->setConfigProfil(PROFIL_ADMIN);
# limite l'acces a l'ecran d'administration du plugin dynamique
			$se=array('PROFIL_ADMIN','PROFIL_MANAGER','PROFIL_MODERATOR','PROFIL_EDITOR','PROFIL_WRITER');
			$re=array(PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR, PROFIL_EDITOR, PROFIL_WRITER);
			$acces = explode(',',str_replace($se,$re,$this->getParam('acces')));
			foreach($acces as $k => $ey)
				$acces[$k] = $ey+0;//INT
//var_dump($acces,(isset($_SESSION['profil']) && in_array($_SESSION['profil'],$acces)),!in_array($_SESSION['user'],explode(',',$this->getParam('deny'))),$_SESSION,explode(',',$this->getParam('deni')));
			if(isset($_SESSION['profil']) && in_array($_SESSION['profil'],$acces) && !in_array($_SESSION['user'],explode(',',$this->getParam('deny'))))
				$this->setAdminProfil((integer)$_SESSION['profil']);#Option pour autorisé le type de profil en dynamique. OU Alors PROFIL_ADMIN , PROFIL_MANAGER , PROFIL_MODERATOR , PROFIL_EDITOR , PROFIL_WRITER
# Personnalisation du menu admin
			$this->setAdminMenu(
				$this->getLang('L_MENU_TAGS')//nom menu//$this->getInfo('title')
				, $this->getLang('P_MENU')//position
				, $this->getLang('L_DESCRIPTION')//$this->getInfo('description')
			);
		}
	}
}
/* Pense-bete:
 * Récuperer des etres du fichier eters.xml
 *	$this->getParam("<nom du etre>")
 *	$this-> setParam ("1", 12345, "numeric")
 *	$this->saveParams()
 *
 *	plxUtils::strCheck($string) : sanitize string
 *
 * 
 * Quelques constantes utiles: 
 * PLX_CORE
 * PLX_ROOT
 * PLX_CHARSET
 * PLX_PLUGINS
 * PLX_CONFIG_PATH
 * PLX_ADMIN (définie si on est dans admin)
 * PLX_CHARSET
 * PLX_VERSION
 * PLX_FEED
 *
 * Appel de HOOK dans un thème
 *	eval($plxShow->callHook("ThemeEndHead","1"))  ou eval($plxShow->callHook("ThemeEndHead",array("1","2")))
 *	ou $retour=$plxShow->callHook("ThemeEndHead","1"));
 */

==> Tagz-1.0.4.zip: Tagz/Tagz.php <==
<?php
/**
* Plugin Tagz
* @package	PLX
* @version	1.0.2
* @date	03/03/2020
* @author Thomas Ingles
**/
class Tagz extends plxPlugin {
	public function __construct($default_lang) {#pluxml 5.8.2 : pourquoi est il appelé alors que non activé ???
		parent::__construct($default_lang);# appel du constructeur de la classe plxPlugin (obligatoire)
		$this->setConfigProfil(PROFIL_ADMIN);# droits pour accéder à la page config.php du plugin

		if(defined('PLX_ADMIN')  AND isset($_SESSION['user'])){#si connecté /*&& !empty($this->getParam('acces'))*/){#si administration et parametré #fix 5.2.8 call if unactivated?
# limite l'acces a l'ecran d'administration du plugin dynamique
			$se=array('PROFIL_ADMIN','PROFIL_MANAGER','PROFIL_MODERATOR','PROFIL_EDITOR','PROFIL_WRITER');
			$re=array(PROFIL_ADMIN, PROFIL_MANAGER, PROFIL_MODERATOR, PROFIL_EDITOR, PROFIL_WRITER);
			$acces = explode(',',str_replace($se,$re,$this->getParam('acces')));
			foreach($acces as $k => $ey)
				$acces[$k] = intval($ey);//INT :: Warning: A non-numeric value encountered if unactivated #fixed by: !empty($this->getParam('acces')
			if(isset($_SESSION['profil']) && in_array($_SESSION['profil'],$acces) && !in_array($_SESSION['user'],explode(',',$this->getParam('deny'))))
				$this->setAdminProfil((integer)$_SESSION['profil']);#Option pour autorisé le type de profil en dynamique. OU Alors PROFIL_ADMIN , PROFIL_MANAGER , PROFIL_MODERATOR , PROFIL_EDITOR , PROFIL_WRITER
# Personnalisation du menu admin
			$this->setAdminMenu(
				$this->getLang('L_MENU_TAGS')//nom menu//$this->getInfo('title')
				, $this->getLang('P_MENU')//position
				, $this->getLang('L_DESCRIPTION')//$this->getInfo('description')
			);
		}
	}
}
/* Pense-bete:
 * Récuperer des etres du fichier eters.xml
 *	$this->getParam("<nom du etre>")
 *	$this-> setParam ("1", 12345, "numeric")
 *	$this->saveParams()
 *
 *	plxUtils::strCheck($string) : sanitize string
 *
 *
 * Quelques constantes utiles:
 * PLX_CORE
 * PLX_ROOT
 * PLX_CHARSET
 * PLX_PLUGINS
 * PLX_CONFIG_PATH
 * PLX_ADMIN (définie si on est dans admin)
 * PLX_CHARSET
 * PLX_VERSION
 * PLX_FEED
 *
 * Appel de HOOK dans un thème
 *	eval($plxShow->callHook("ThemeEndHead","1"))  ou eval($plxShow->callHook("ThemeEndHead",array("1","2")))
 *	ou $retour=$plxShow->callHook("ThemeEndHead","1"));
 */
